@@ -1,4 +1,4 @@
-"""A bash kernel for Jupyter"""
+"""A clingo kernel for Jupyter"""
 
 from pathlib import Path
 from single_source import get_version
